pub fn perspective(
vertical_fov: f64,
aspect_ratio: f64,
near: f64,
far: f64,
) -> DMat4Expand description
Creates a perspective projection matrix for use with Vulkan.
Expects a right-handed Y-up view space input. Outputs NDC with Z in [0, 1] and Y-down.
Panics
Will panic if near or far are less than or equal to zero when glam_assert is enabled.